@@ -13,17 +13,15 @@ class dc_tanf_demographic_eligible_person(Variable):
     defined_for = StateCode.DC
 
     def formula(person, period, parameters):
-        p = parameters(period).gov.states.dc.dhs.tanf.age_threshold
-        age = person("monthly_age", period)
-        dependent = person("is_tax_unit_dependent", period)
-        minor_child = age < p.minor_child
-        eligible_minor_child = minor_child & dependent
-
-        student_dependent = age < p.student_dependent
-        secondary_school_student = person("is_in_secondary_school", period)
-        eligible_student_dependent = (
-            secondary_school_student & student_dependent & dependent
+        pap_eligible_child = person("dc_pap_eligible_child", period)
+        related_to_head_or_spouse = person(
+            "is_related_to_head_or_spouse", period
+        )
+        pregnant = person("is_pregnant", period)
+        immigration_status_eligible = person(
+            "dc_tanf_immigration_status_eligible_person", period
         )
 
-        pregnant = person("is_pregnant", period)
-        return eligible_minor_child | eligible_student_dependent | pregnant
+        return (pap_eligible_child & related_to_head_or_spouse) | (
+            pregnant & immigration_status_eligible
+        )
