@@ -16,12 +16,13 @@ class il_tanf_initial_employment_deduction_person(Variable):
         ).gov.states.il.dhs.tanf.income.initial_employment_deduction
 
         gross_earned_income = person("il_tanf_gross_earned_income", period)
-        fpg = person.spm_unit("spm_unit_fpg", period)
+        fpg = person.spm_unit(
+            "il_tanf_initial_employment_deduction_fpg", period
+        )
         payment_level = person.spm_unit(
             "il_tanf_payment_level_for_initial_eligibility", period
         )
-
-        initial_employment_deduction = p.rate * fpg - payment_level
+        initial_employment_deduction = max_(p.rate * fpg - payment_level, 0)
         is_employed = gross_earned_income > 0
         is_head_or_spouse = person("is_tax_unit_head_or_spouse", period)
         ied_eligible_person = is_employed & is_head_or_spouse
