@@ -17,5 +17,5 @@ class mn_income_tax_before_refundable_credits(Variable):
 
     def formula(tax_unit, period, parameters):
         itax_before_credits = tax_unit("mn_income_tax_before_credits", period)
-        nonrefundable_credits = tax_unit("mn_nonrefundable_credits", period)
+        nonrefundable_credits = tax_unit("mn_non_refundable_credits", period)
         return max_(0, itax_before_credits - nonrefundable_credits)
