@@ -13,4 +13,8 @@ class or_income_subtractions(Variable):
     )
     defined_for = StateCode.OR
 
-    adds = "gov.states.or.tax.income.subtractions.subtractions"
+    def formula(tax_unit, period, parameters):
+        p = parameters(period).gov.states["or"].tax.income.subtractions
+        total_subtractions = add(tax_unit, period, p.subtractions)
+        # Prevent negative subtractions from acting as additions
+        return max_(0, total_subtractions)
