@@ -7,4 +7,4 @@ class medicare_part_b_premiums(Variable):
     label = "Medicare Part B premiums"
     definition_period = YEAR
     unit = USD
-    uprating = "gov.bls.cpi.cpi_u"
+    uprating = "calibration.gov.hhs.cms.moop_per_capita"
